﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Data;
using Vevo.Shared.DataAccess;

namespace Vevo.Data.Implementation
{
    internal class BlogStoreAccess
    {
        #region Private

        private IList<String> ConvertToStoreIDs( DataTable table )
        {
            IList<String> list = new List<String>();
            foreach (DataRow row in table.Rows)
            {
                list.Add( row["StoreID"].ToString() );
            }

            return list;
        }

        #endregion

        #region Public Methods

        public void SaveAll( string blogID, IList<String> storeIDs )
        {
            DeleteByBlogID( blogID );
            Create( blogID, storeIDs );
        }

        public void Create( string blogID, IList<String> storeIDs )
        {
            foreach (string storeID in storeIDs)
            {
                int result = DataAccess.ExecuteNonQuery(
                    "INSERT INTO BlogStore (BlogID, StoreID) " +
                    "VALUES (@BlogID, @StoreID); ",
                    DataAccess.CreateParameterString( blogID ),
                    DataAccess.CreateParameterString( storeID ) );

                if (result != 1)
                {
                    Exception exception = new ApplicationException(
                            "Failed creating blog. " +
                        "Inserting into BlogStore returns " + result.ToString() );
                    DataAccessHelper.LogError( exception );
                    throw exception;
                }
            }
        }

        public void DeleteByBlogID( string blogID )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE " +
                "FROM BlogStore " +
                "WHERE BlogID = @BlogID; ",
                DataAccess.CreateParameterString( blogID ) );
        }

        public IList<String> GetByBlogID( string blogID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT StoreID " +
                "FROM BlogStore " +
                "WHERE BlogID = @BlogID; ",
                DataAccess.CreateParameterString( blogID ) );

            return ConvertToStoreIDs( table );
        }

        #endregion
    }
}
