using System;
using System.Collections.Generic;
using System.Text;

using Vevo.Domain;
using Vevo.Domain.Configurations;
using Vevo.Shared.DataAccess;
using Vevo.Base.Data.Implementation;

namespace Vevo.Data.Implementation
{
    internal class ConfigurationValueAccess : BaseListedDataAccess<string, ConfigurationValue>
    {
        #region Protected

        protected override void Create( string configID, ConfigurationValue item )
        {
            DataAccess.ExecuteNonQuery(
                "INSERT INTO ConfigurationValue (ConfigID, CultureID, ItemValue, StoreID) " +
                "VALUES (@ConfigID, @CultureID, @ItemValue, @StoreID); ",
                DataAccess.CreateParameterString( configID ),
                DataAccess.CreateParameterString( item.CultureID ),
                DataAccess.CreateParameterString( item.ItemValue ),
                DataAccess.CreateParameterString( item.StoreID ) );
        }

        protected override void Update( string configID, ConfigurationValue item )
        {
            DataAccess.ExecuteNonQuery(
                "UPDATE ConfigurationValue " +
                "SET ItemValue = @ItemValue " +
                "WHERE ConfigID = @ConfigID AND CultureID = @CultureID AND StoreID = @StoreID; ",
                DataAccess.CreateParameterString( item.ItemValue ),
                DataAccess.CreateParameterString( configID ),
                DataAccess.CreateParameterString( item.CultureID ),
                DataAccess.CreateParameterString( item.StoreID ) );
        }

        protected override void Delete( string configID, ConfigurationValue item )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE FROM ConfigurationValue " +
                "WHERE ConfigID = @ConfigID AND CultureID = @CultureID AND StoreID = @StoreID; ",
                DataAccess.CreateParameterString( configID ),
                DataAccess.CreateParameterString( item.CultureID ),
                DataAccess.CreateParameterString( item.StoreID ) );
        }

        #endregion


        #region Public Methods

        public void Save( string configID, string newValue )
        {
            Save( "0", configID, newValue, "0" );
        }

        public void Save( string configID, string newValue, string storeID )
        {
            Save( "0", configID, newValue, storeID );
        }

        public void Save( string cultureID, string configID, string newValue, string storeID )
        {
            int result = DataAccess.ExecuteNonQuery(
                "UPDATE ConfigurationValue " +
                "SET ItemValue = @ItemValue " +
                "WHERE ConfigID = @ConfigID AND CultureID = @CultureID AND StoreID = @StoreID ",
                DataAccess.CreateParameterString( newValue ),
                DataAccess.CreateParameterString( configID ),
                DataAccess.CreateParameterString( cultureID ),
                DataAccess.CreateParameterString( storeID ) );

            if (result == 0)
            {
                result = DataAccess.ExecuteNonQuery(
                    "INSERT INTO ConfigurationValue (ConfigID, CultureID, ItemValue, StoreID) " +
                    "VALUES (@ConfigID, @CultureID, @ItemValue, @StoreID); ",
                    DataAccess.CreateParameterString( configID ),
                    DataAccess.CreateParameterString( cultureID ),
                    DataAccess.CreateParameterString( newValue ),
                    DataAccess.CreateParameterString( storeID ) );

                if (result == 0)
                {
                    Exception exception = new DataException(
                        "Failed creating configuration item '" + configID + "'. " +
                        "Inserting ConfigurationValue returns " + result.ToString() );
                    DataAccessHelper.LogError( exception );
                    throw exception;
                }
            }
        }

        #endregion

    }
}
