using System;
using System.Collections.Generic;
using System.Text;
using System.Web.UI;
using Vevo.Base.Data.Caching;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.Shipping;
using Vevo.Shared.Utilities;
using Vevo.Base.Domain;

namespace Vevo.Data
{
    public class ShippingOrderTotalRateRepository : IShippingOrderTotalRateRepository
    {
        #region Private

        private const string RepositoryName = "ShippingOrderTotalRateRepository";

        private const string GetOneSignature = "GetOne";
        private const string SearchShippingOrderTotalRateItemSignature = "SearchShippingOrderTotalRateItem";
        private const string GetAllByShippingIDSignature = "GetAllByShippingID";
        private const string GetTableSchemaSignature = "GetTableSchema";
        private const string TableName = "ShippingOrderTotalRate";
        private DataCache _dataCache = new DataCache( RepositoryName );
        private ICacheDependencyUtility _cacheDependency = new CacheDependencyUtility( TableName );

        private ShippingOrderTotalRateRepositoryNoCache _repository = new ShippingOrderTotalRateRepositoryNoCache();

        #endregion

        #region Constructors

        public ShippingOrderTotalRateRepository()
        {
        }

        public ShippingOrderTotalRateRepository( ICacheDependencyUtility cacheDependency )
        {
            _cacheDependency = cacheDependency;
        }

        #endregion

        #region Public Methods

        public ShippingOrderTotalRate Save( ShippingOrderTotalRate shippingOrderTotalRate )
        {
            // Need to write to database first before clearing cache.
            // Otherwise, cache may remember incorrect values before saving.
            ShippingOrderTotalRate newShippingOrderTotalRate = _repository.Save( shippingOrderTotalRate );
            _dataCache.ClearRepositoryCache();
            return newShippingOrderTotalRate;
        }

        public ShippingOrderTotalRate GetOne( string shippingOrderTotalRateID )
        {
            ShippingOrderTotalRate result = (ShippingOrderTotalRate) _dataCache.GetValue(
                GetOneSignature,
                _cacheDependency,
                shippingOrderTotalRateID );

            if (result == null)
            {
                result = _repository.GetOne( shippingOrderTotalRateID );
                _dataCache.SetValue( GetOneSignature, result, shippingOrderTotalRateID );
            }

            return result;
        }

        public void Delete( string shippingOrderTotalRateID )
        {
            _repository.Delete( shippingOrderTotalRateID );
            _dataCache.ClearRepositoryCache();
        }

        public void DeleteByShippingID( string shippingID )
        {
            _repository.DeleteByShippingID( shippingID );
            _dataCache.ClearRepositoryCache();
        }

        public IList<ShippingOrderTotalRate> GetAllByShippingID( string shippingID, string sortBy )
        {
            IList<ShippingOrderTotalRate> list = (IList<ShippingOrderTotalRate>) _dataCache.GetValue(
                   GetAllByShippingIDSignature,
                   _cacheDependency,
                   shippingID,
                   sortBy
                   );

            if (list == null)
            {
                list = _repository.GetAllByShippingID( shippingID, sortBy );
                _dataCache.SetValue(
                    GetAllByShippingIDSignature,
                    list,
                    shippingID,
                    sortBy
                    );
            }

            return list;
        }

        public IList<ShippingOrderTotalRate> SearchShippingOrderTotalRateItem(
            string shippingID,
            string sortBy,
            SearchFilter searchFilter,
            int startIndex,
            int endIndex,
            out int howManyItems
            )
        {
            howManyItems = 0;
            Pair result = (Pair) _dataCache.GetValue(
                SearchShippingOrderTotalRateItemSignature,
                _cacheDependency,
                shippingID,
                sortBy,
                searchFilter.ToString(),
                startIndex,
                endIndex
                );

            if (result == null)
            {
                result = new Pair();
                result.First = _repository.SearchShippingOrderTotalRateItem(
                    shippingID, sortBy, searchFilter, startIndex, endIndex, out howManyItems );
                result.Second = howManyItems;
                _dataCache.SetValue(
                    SearchShippingOrderTotalRateItemSignature,
                    result,
                    shippingID,
                    sortBy,
                    searchFilter.ToString(),
                    startIndex,
                    endIndex );
            }

            howManyItems = ConvertUtilities.ToInt32( result.Second );
            return (IList<ShippingOrderTotalRate>) result.First;
        }

        public IList<TableSchemaItem> GetTableSchema()
        {
            IList<TableSchemaItem> list = (IList<TableSchemaItem>) _dataCache.GetValue(
                   GetTableSchemaSignature, _cacheDependency
                   );

            if (list == null)
            {
                list = _repository.GetTableSchema();
                _dataCache.SetValue(
                    GetTableSchemaSignature,
                    list
                    );
            }

            return list;
        }

        #endregion

    }
}
