using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using System.Text;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.Shipping;
using Vevo.Shared.DataAccess;
using Vevo.Shared.Utilities;
using Vevo.Base.Data;
using Vevo.Base.Domain;

namespace Vevo.Data
{
    public class ShippingOrderTotalRateRepositoryNoCache : IShippingOrderTotalRateRepository
    {

        #region Private

        private const string AllFields = "ShippingOrderTotalRateID, ShippingID, ToOrderTotal, ShippingOrderTotalRate ";

        private string CreateSortByText( string sortBy )
        {
            if (sortBy == null || sortBy.Trim() == "")
                return "";
            else
                return "ORDER BY " + sortBy + " ";
        }

        private ShippingOrderTotalRate Create( ShippingOrderTotalRate shippingOrderTotalRate )
        {
            string newID = DataAccess.ExecuteScalar(
                "INSERT INTO ShippingOrderTotalRate (ShippingID, ToOrderTotal, ShippingOrderTotalRate) " +
                "VALUES (@ShippingID, @ToOrderTotal, @ShippingOrderTotalRate);" +
                "SELECT @@Identity; ",
                DataAccess.CreateParameterString( shippingOrderTotalRate.ShippingID ),
                DataAccess.CreateParameterDecimalMoney( shippingOrderTotalRate.ToOrderTotal ),
                DataAccess.CreateParameterDecimalMoney( shippingOrderTotalRate.OrderTotalRate )
            );
            shippingOrderTotalRate.ShippingOrderTotalRateID = newID;
            return shippingOrderTotalRate;
        }

        private ShippingOrderTotalRate Update( ShippingOrderTotalRate shippingOrderTotalRate )
        {
            DataAccess.ExecuteNonQuery(
                "UPDATE ShippingOrderTotalRate " +
                "SET ToOrderTotal = @ToOrderTotal, " +
                "ShippingOrderTotalRate = @ShippingOrderTotalRate " +
                "WHERE ShippingOrderTotalRateID = @ShippingOrderTotalRateID;",
                DataAccess.CreateParameterDecimalMoney( shippingOrderTotalRate.ToOrderTotal ),
                DataAccess.CreateParameterDecimalMoney( shippingOrderTotalRate.OrderTotalRate ),
                DataAccess.CreateParameterString( shippingOrderTotalRate.ShippingOrderTotalRateID )
            );
            return shippingOrderTotalRate;
        }

        private ShippingOrderTotalRate CreateOneFromRow( DataRow row )
        {
            ShippingOrderTotalRate shippingOrderTotalRate = new ShippingOrderTotalRate();

            shippingOrderTotalRate.ShippingOrderTotalRateID = row["ShippingOrderTotalRateID"].ToString();
            shippingOrderTotalRate.ShippingID = row["ShippingID"].ToString();
            shippingOrderTotalRate.ToOrderTotal = ConvertUtilities.ToDecimal( row["ToOrderTotal"] );
            shippingOrderTotalRate.OrderTotalRate = ConvertUtilities.ToDecimal( row["ShippingOrderTotalRate"] );

            return shippingOrderTotalRate;
        }

        private IList<ShippingOrderTotalRate> ConvertTableToList( DataTable table )
        {
            return ConvertTableToList( table, 0, table.Rows.Count );
        }

        private IList<ShippingOrderTotalRate> ConvertTableToList( DataTable table, int startIndex, int endIndex )
        {
            IList<ShippingOrderTotalRate> list = new List<ShippingOrderTotalRate>();

            for (int i = startIndex; i <= endIndex && i < table.Rows.Count; i++)
                list.Add( CreateOneFromRow( table.Rows[i] ) );

            return list;
        }

        #endregion

        #region Public Methods
        public ShippingOrderTotalRate Save( ShippingOrderTotalRate shippingOrderTotalRate )
        {
            ShippingOrderTotalRate result;
            if (shippingOrderTotalRate.ShippingOrderTotalRateID == "0")
                result = Create( shippingOrderTotalRate );
            else
                result = Update( shippingOrderTotalRate );
            return result;
        }

        public ShippingOrderTotalRate GetOne( string shippingOrderTotalRateID )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllFields +
                " FROM ShippingOrderTotalRate " +
                "WHERE ShippingOrderTotalRateID = @ShippingOrderTotalRateID;",
                DataAccess.CreateParameterString( shippingOrderTotalRateID ) );

            if (table.Rows.Count > 0)
                return CreateOneFromRow( table.Rows[0] );
            else
                return null;
        }

        public void Delete( string shippingOrderTotalRateID )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE FROM ShippingOrderTotalRate " +
                "WHERE ShippingOrderTotalRateID = @ShippingOrderTotalRateID;",
                DataAccess.CreateParameterString( shippingOrderTotalRateID )
            );
        }

        public void DeleteByShippingID( string shippingID )
        {
            DataAccess.ExecuteNonQuery(
                "DELETE FROM ShippingOrderTotalRate " +
                "WHERE ShippingID = @ShippingID;",
                DataAccess.CreateParameterString( shippingID )
            );
        }

        public IList<ShippingOrderTotalRate> GetAllByShippingID( string shippingID, string sortBy )
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllFields +
                "FROM ShippingOrderTotalRate " +
                "WHERE ShippingID = @ShippingID " +
                CreateSortByText( sortBy ) + "; ",
                DataAccess.CreateParameterString( shippingID )
                );
            DataColumn[] keys = new DataColumn[1] { table.Columns["ShippingOrderTotalRateID"] };
            table.PrimaryKey = keys;
            return ConvertTableToList( table );
        }

        public IList<ShippingOrderTotalRate> SearchShippingOrderTotalRateItem(
    string shippingID,
    string sortBy,
    SearchFilter searchFilter,
    int startIndex,
    int endIndex,
    out int howManyItems
    )
        {
            ArrayList parameterList = new ArrayList();
            SearchFilterHelperNew searchFilterHelper = new SearchFilterHelperNew();
            string commandSearch = searchFilterHelper.CreateCommandWithWhere( searchFilter, searchFilter.FieldName, parameterList );
            parameterList.Add( DataAccess.CreateParameterString( shippingID ) );

            DataTable full = DataAccess.ExecuteSelect(
                "SELECT " + AllFields +
                " FROM ShippingOrderTotalRate " +
                commandSearch +
                "AND ShippingID = @ShippingID " +
                CreateSortByText( sortBy ) + "; ",
                DataAccess.ConvertArrayListToDbParameters( parameterList )
                );

            howManyItems = full.Rows.Count;

            DataColumn[] keys = new DataColumn[] { full.Columns["ShippingOrderTotalRateID"] };
            full.PrimaryKey = keys;
            return ConvertTableToList( full, startIndex, endIndex );
        }

        public IList<TableSchemaItem> GetTableSchema()
        {
            DataTable table = DataAccess.ExecuteSelect(
                "SELECT " + AllFields +
                "FROM  ShippingOrderTotalRate; "
                );

            return RepositoryUtilities.ConvertTableToSchemaItemList( table );
        }

        #endregion
    }
}
