using System;
using System.Collections.Generic;
using System.IO;
using System.Text;
using Vevo.Shared.Domain.SystemServices;

namespace Vevo.Domain.Orders
{
    [Serializable]
    public class TempUploadedFile
    {
        #region Private

        private IFileManager _fileManager;

        private string _tempRelativePath;
        private string _actualRelativePath;

        private string _tempFileName;

        #endregion


        #region Constructors

        public TempUploadedFile(
            IFileManager fileManager,
            string tempRelativePath,
            string actualRelativePath,
            string uploadedFileName )
        {
            _fileManager = fileManager;
            _tempRelativePath = tempRelativePath;
            _actualRelativePath = actualRelativePath;


            _tempFileName = Guid.NewGuid().ToString() + "_" + uploadedFileName;
        }

        #endregion


        #region Public Methods

        public string GetTempFileName()
        {
            return _tempFileName;
        }

        public string GetTempFileLocalPath()
        {
            string path = Path.Combine( _tempRelativePath, _tempFileName );
            path = Path.Combine( "~/", path );
            return _fileManager.GetFullPath( path );
        }

        public void MoveToActualFolder( string destinationFileName )
        {
            string sourcePath = Path.Combine( "~/", Path.Combine( _tempRelativePath, _tempFileName ));
            string destinationPath = Path.Combine( "~/",Path.Combine( _actualRelativePath, destinationFileName ));

            _fileManager.Move( sourcePath, destinationPath );
        }

        #endregion

    }
}
