using System;
using System.Collections.Generic;
using System.Text;
using Vevo.Domain.Base;

namespace Vevo.Domain.Products
{
    public class OptionGroup : ILocaleLoader, ICloneable
    {
        #region Enum Type
        public enum OptionGroupType
        {
            Radio,
            DropDown,
            Text,
            InputList,
            Upload,
            UploadRequired,
            Unknown
        }
        #endregion


        #region Private

        private string _optionGroupID = "0";
        private OptionGroupType _type = OptionGroupType.Unknown;

        private Culture _defaultCulture;
        private LocaleCollection<OptionGroupLocale> _locales;

        #endregion


        #region Public Properties

        public static OptionGroup Null
        {
            get { return NullOptionGroup.Instance; }
        }

        public virtual bool IsNull
        {
            get { return false; }
        }

        public string OptionGroupID { get { return _optionGroupID; } set { _optionGroupID = value; } }
        public OptionGroupType Type { get { return _type; } set { _type = value; } }

        public Culture DefaultCulture { get { return _defaultCulture; } set { _defaultCulture = value; } }
        public LocaleCollection<OptionGroupLocale> Locales { get { return _locales; } }

        //------------------------------------------------------------
        // Locale items
        public string Name
        {
            get { return Locales[DefaultCulture].Name; }
            set { Locales.GetNoLoad( DefaultCulture ).Name = value; }
        }
        public string DisplayText
        {
            get { return Locales[DefaultCulture].DisplayText; }
            set { Locales.GetNoLoad( DefaultCulture ).DisplayText = value; }
        }
        // End Locale items
        //------------------------------------------------------------

        #endregion


        #region Custom Properties

        public IList<OptionItem> OptionItems
        {
            get
            {
                return DataAccessContext.OptionItemRepository.GetByOptionGroupID( DefaultCulture, OptionGroupID );
            }
        }

        #endregion


        #region Public Constructors

        public OptionGroup( Culture defaultCulture )
        {
            _defaultCulture = defaultCulture;
            _locales = new LocaleCollection<OptionGroupLocale>( this );
        }

        #endregion


        #region ILocaleLoader Members

        public IList<ILocale> GetLocales()
        {
            List<ILocale> result = new List<ILocale>();

            foreach (OptionGroupLocale locale in DataAccessContext.OptionGroupRepository.GetLocales( OptionGroupID ))
                result.Add( locale );

            return result;
        }

        #endregion


        #region IClonable Members

        // Copy the whole aggregate (including locale)
        public object Clone()
        {
            OptionGroup newObject = (OptionGroup) MemberwiseClone();
            newObject._locales = (LocaleCollection<OptionGroupLocale>) Locales.Clone();

            return newObject;
        }

        #endregion


        #region Public Methods

        #endregion
    }

}
