using System;
using System.Collections;
using System.Collections.Generic;
using System.Data;
using System.Text;
using Vevo.Shared.DataAccess;
using Vevo.Shared.DataAccess.Implementation;

namespace Vevo.Reports
{
    public class ShippingReportBuilder
    {
        private DataTable GetShippingMethodReport(
            string sortBy,
            PeriodType period,
            DateTime startOrderDate,
            DateTime endOrderDate )
        {
            ArrayList parameters = new ArrayList();
            string from1, from2, to1, to2;

            parameters.Add( DataAccess.CreateParameterBool( true ) );
            parameters.Add( DataAccess.CreateParameterBool( true ) );
            parameters.Add( DataAccess.CreateParameterBool( false ) );
            if (period == PeriodType.Last24Hours)
            {
                from1 = DateFilterHelper.CreateFromDateFor24HoursWithAnd(
                    startOrderDate, parameters, "from1", "OrderDate" );
                to1 = DateFilterHelper.CreateToDateFor24HoursWithAnd(
                    endOrderDate, parameters, "to1", "OrderDate" );
            }
            else
            {
                from1 = DateFilterHelper.CreateFromDateWithAnd(
                    startOrderDate, parameters, "from1", "OrderDate" );
                to1 = DateFilterHelper.CreateToDateWithAnd(
                    endOrderDate, parameters, "to1", "OrderDate" );
            }
            parameters.Add( DataAccess.CreateParameterBool( true ) );
            parameters.Add( DataAccess.CreateParameterBool( true ) );
            parameters.Add( DataAccess.CreateParameterBool( false ) );
            if (period == PeriodType.Last24Hours)
            {
                from2 = DateFilterHelper.CreateFromDateFor24HoursWithAnd(
                    startOrderDate, parameters, "from2", "OrderDate" );
                to2 = DateFilterHelper.CreateToDateFor24HoursWithAnd(
                    endOrderDate, parameters, "to2", "OrderDate" );
            }
            else
            {
                from2 = DateFilterHelper.CreateFromDateWithAnd(
                    startOrderDate, parameters, "from2", "OrderDate" );
                to2 = DateFilterHelper.CreateToDateWithAnd(
                    endOrderDate, parameters, "to2", "OrderDate" );
            }


            string sort;
            if (string.IsNullOrEmpty( sortBy ))
            {
                sort = "";
            }
            else
            {
                string[] sortArray = sortBy.Split( ' ' );
                if (sortBy.Contains( "SumShippingMethod" ))
                {
                    sort = "ORDER BY COUNT(ShippingMethod) " + sortArray[1];
                }
                else if (sortBy.Contains( "Percentage" ))
                {
                    sort = "ORDER BY " +
                        DbImplementation.Sql.CreateDivideFucntion(
                        "(COUNT(ShippingMethod)*100)", "TotalShippingMethod" ) +
                        sortArray[1];
                }
                else
                {
                    sort = "ORDER BY " + sortBy;
                }
            }

            string script = "SELECT COUNT(ShippingMethod) as SumShippingMethod, Orders.ShippingMethod, " +
                DbImplementation.Sql.CreateDivideFucntion( "(COUNT(ShippingMethod)*100)", "TotalShippingMethod" )
                + " as Percentage " +
                "FROM Orders, " +
                "(SELECT COUNT(ShippingMethod) as TotalShippingMethod " +
                "FROM Orders " +
                "WHERE PaymentComplete = @PaymentComplete AND " +
                "Processed = @Processed And Cancelled = @Cancelled" +
                from1 +
                to1 +
                ") as O " +
                "WHERE PaymentComplete = @PaymentComplete1 AND " +
                "Processed = @Processed1 And Cancelled = @Cancelled1 " +
                from2 +
                to2 +
                "GROUP BY ShippingMethod, TotalShippingMethod " +
                sort;

            return DataAccess.ExecuteSelect( script, DataAccess.ConvertArrayListToDbParameters( parameters ) );
        }

        private DataTable GetShippingMethodReport(
            string sortBy,
            DateTime startOrderDate,
            DateTime endOrderDate,
            int startIndex,
            int endIndex,
            PeriodType period,
            out int howManyItems )
        {
            DataTable full = GetShippingMethodReport( sortBy, period, startOrderDate, endOrderDate );

            howManyItems = full.Rows.Count;

            DataColumn[] keys = new DataColumn[] { full.Columns["ShippingMethod"] };
            full.PrimaryKey = keys;
            return DataAccess.CopyTableRows( full, startIndex, endIndex );
        }

        public DataTable GetShippingReportData(
            PeriodType period,
            DateTime startOrderDate,
            DateTime endOrderDate )
        {
            DataTable table = GetShippingMethodReport(
                "",
                period,
                startOrderDate,
                endOrderDate );

            return table;
        }

        public DataTable GetShippingReportData(
            string sortBy,
            PeriodType period,
            DateTime startOrderDate,
            DateTime endOrderDate,
            int startIndex,
            int endIndex,
            out int totalItems )
        {
            DataTable table = GetShippingMethodReport(
                sortBy,
                startOrderDate,
                endOrderDate,
                startIndex,
                endIndex,
                period,
                out totalItems );

            return table;
        }
    }
}
