﻿using System;
using System.Collections.Generic;
using System.Text;
using System.ServiceModel;
using Vevo.WebServices.Base;
using Vevo.WebServices.Security;
using Vevo.WebServices.SearchFilters;
using Vevo.WebAppLib;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain;
using System.Data;
using Vevo.Domain.Discounts;
using Vevo.Base.Domain;

namespace Vevo.WebServices.QuantityDiscounts
{
    public class QuantityDiscountService : IQuantityDiscountService
    {
        private QuantityDiscountConstraints ConvertQuantityDiscountToConstraints( DiscountGroup quantityDiscount )
        {
            QuantityDiscountConstraints constraints = new QuantityDiscountConstraints();
            constraints.DiscountGroupID = quantityDiscount.DiscountGroupID;
            constraints.DiscountType = quantityDiscount.DiscountType;
            constraints.GroupName = quantityDiscount.GroupName;
            constraints.ProductOptionDiscount = quantityDiscount.ProductOptionDiscount;

            foreach (DiscountRule discountRule in quantityDiscount.DiscountRules)
            {
                QuantityDiscountRuleConstraints subconstraint = new QuantityDiscountRuleConstraints();
                subconstraint.Amount = discountRule.Amount;
                subconstraint.DiscountGroupID = discountRule.DiscountGroupID;
                subconstraint.DiscountRuleID = discountRule.DiscountRuleID;
                subconstraint.Percentage = discountRule.Percentage;
                subconstraint.ToItems = discountRule.ToItems;

                if ( constraints.DiscountRules == null )
                    constraints.DiscountRules = new List<QuantityDiscountRuleConstraints>();
                constraints.DiscountRules.Add( subconstraint );
            }

            return constraints;
        }

        public QuantityDiscountListResponseMessage ListQuantityDiscounts( QuantityDiscountListRequestMessage ListMessage )
        {
            QuantityDiscountListResponseMessage responseMessage = new QuantityDiscountListResponseMessage();
            if ( WcfSessionPool.GetSession( ListMessage.Ticket ) == null )
            {
                responseMessage.ErrorMessage = "Error: Authentication is failed.";
                return responseMessage;
            }
            try
            {
                SearchFilter searchFilter = SearchFilterUtilities.ConvertConstraintToSearchFilter( ListMessage.SearchFilter );
                int quantityDiscountCount = 0;
                IList<DiscountGroup> quantityDiscount_result = DataAccessContext.DiscountGroupRepository.SearchDiscountGroup
                    ( "DiscountGroupID", searchFilter, ListMessage.SearchFilter.StartIndex, ListMessage.SearchFilter.EndIndex, 
                    out quantityDiscountCount );
                responseMessage.QuantityDiscounts = new List<QuantityDiscountConstraints>();
                foreach ( DiscountGroup quantityDiscount in quantityDiscount_result )
                {
                    responseMessage.QuantityDiscounts.Add( ConvertQuantityDiscountToConstraints( quantityDiscount ) );
                }
            }
            catch ( Exception e )
            {
                WebUtilities.LogError( e );
                responseMessage.ErrorMessage = "Error: Cannot get quantity discounts from repository";
            }

            return responseMessage;
        }
    }
}
