﻿using System;
using System.Collections.Generic;
using System.Text;
using System.ServiceModel;
using Vevo.WebServices.Base;
using Vevo.WebServices.Security;
using Vevo.WebServices.SearchFilters;
using Vevo.Domain;
using Vevo.Domain.DataInterfaces;
using Vevo.Domain.Stores;
using Vevo.WebAppLib;
using Vevo.Base.Domain;

namespace Vevo.WebServices.Stores
{
    public class StoreService : IStoreService
    {
        private StoreConstraints ConvertStoreToConstraints( Store store )
        {
            StoreConstraints constraints = new StoreConstraints();
            constraints.IsEnabled = store.IsEnabled;
            constraints.StoreID = store.StoreID;
            constraints.StoreName = store.StoreName;
            constraints.UrlName = store.UrlName;
            return constraints;
        }

        public StoreListResponseMessage ListStores( StoreListRequestMessage ListMessage )
        {
            StoreListResponseMessage responseMessage = new StoreListResponseMessage();
            if (WcfSessionPool.GetSession( ListMessage.Ticket ) == null)
            {
                responseMessage.ErrorMessage = "Error: Authentication is failed.";
                return responseMessage;
            }
            try
            {
                SearchFilter searchFilter = SearchFilterUtilities.ConvertConstraintToSearchFilter(
                                ListMessage.SearchFilter );
                int storeCount = 0;
                IList<Store> store_result = DataAccessContext.StoreRepository.SearchStore( "StoreID", searchFilter, ListMessage.SearchFilter.StartIndex, ListMessage.SearchFilter.EndIndex, out storeCount );
                responseMessage.Stores = new List<StoreConstraints>();
                foreach (Store store in store_result)
                {
                    responseMessage.Stores.Add( ConvertStoreToConstraints( store ) );
                }
            }
            catch (Exception e)
            {
                WebUtilities.LogError( e );
                responseMessage.ErrorMessage = "Error: Cannot get stores from repository";
            }

            return responseMessage;
        }
    }
}
