using System;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.WebControls;
using Vevo.Domain;
using Vevo.WebAppLib;
using Vevo.WebUI.International;

namespace Vevo.WebUI.BaseControls
{
    /// <summary>
    /// Summary description for BaseLayoutControl
    /// </summary>
    public abstract class BaseLayoutControl : BaseLanguageUserControl
    {
        private bool IsVerified
        {
            get
            {
                bool verified = false;

                if (Session["LayoutControlsIsVerified"] != null)
                    verified = (bool) Session["LayoutControlsIsVerified"];

                if (!verified)
                {
                    if (KeyUtilities.Verify( NamedConfig.DomainRegistrationKey ) ||
                        KeyUtilities.VerifyLicenseFile( Server.MapPath( SystemConst.LicenseFilePath ) ))
                    {
                        verified = true;
                    }

                    Session["LayoutControlsIsVerified"] = verified;
                }
                return verified;
            }
        }


        private Control FindControlEx( Control parent, string id, bool recursive )
        {
            if (recursive)
                return WebUtilities.FindControlRecursive( parent, id );
            else
                return parent.FindControl( id );
        }

        private Login FindLogin()
        {
            return (Login) FindControl( "uxLogin" );
        }

        private string FindCouponID()
        {
            TextBox couponIDText = ((TextBox) FindControl( "uxCouponIDText" ));
            return couponIDText.Text;
        }

        private string FindSearchText()
        {
            TextBox searchText = ((TextBox) FindControl( "uxSearchText" ));
            return searchText.Text;
        }

        private void TieSearchControls( Control parent, bool recursive )
        {
            Control searchText = FindControlEx( parent, "uxSearchText", recursive );
            if (searchText != null)
            {
                Control searchButton = FindControlEx( parent, "uxSearchButton", recursive );
                if (searchButton != null)
                    WebUtilities.TieButton( this.Page, searchText, searchButton );

                Control searchImageButton = FindControlEx( parent, "uxSearchImageButton", recursive );
                if (searchImageButton != null)
                    WebUtilities.TieButton( this.Page, searchText, searchImageButton );
            }
        }

        private void TieCouponControls( Control parent, bool recursive )
        {
            Control textBox = FindControlEx( parent, "uxCouponIDText", recursive );
            if (textBox != null)
            {
                Control button = FindControlEx( parent, "uxCouponButton", recursive );
                if (button != null)
                    WebUtilities.TieButton( this.Page, textBox, button );

                Control imageButton = FindControlEx( parent, "uxCouponImageButton", recursive );
                if (imageButton != null)
                    WebUtilities.TieButton( this.Page, textBox, imageButton );
            }
        }


        public BaseLayoutControl()
        {
            Load += new EventHandler( LoginHandler );
            Load += new EventHandler( TieSearchControlHandler );
            Load += new EventHandler( TieCouponControlHandler );
            Load += new EventHandler( KeyHandler );
        }

        protected void LoginHandler( object sender, EventArgs e )
        {
            Login login = FindLogin();
            if (login != null)
            {
                if (Membership.GetUser( false ) != null)
                {
                    login.Visible = false;
                    // Status.Visible = true;
                    Panel panel = (Panel) FindControl( "uxHeadPanel" );
                    panel.Visible = true;
                }
                else
                {
                    login.Visible = true;
                    // Status.Visible = false;
                    Panel panel = (Panel) FindControl( "uxHeadPanel" );
                    panel.Visible = false;
                }
            }
        }

        protected void TieSearchControlHandler( object sender, EventArgs e )
        {
            Control control = FindControl( "uxSearch" );
            if (control != null)
                TieSearchControls( control, true );
            else
                TieSearchControls( this, false );
        }

        protected void TieCouponControlHandler( object sender, EventArgs e )
        {
            Control control = FindControl( "uxVerifyCoupon" );
            if (control != null)
                TieCouponControls( control, true );
            else
                TieCouponControls( this, false );
        }

        protected void KeyHandler( object sender, EventArgs e )
        {
            if (!IsVerified)
                Response.Redirect( "KeyValidationError.aspx" );
        }

        protected void uxSearchButton_Click( object sender, EventArgs e )
        {
            Response.Redirect( "SearchResult.aspx?Search=" + FindSearchText() );
        }

        protected void uxSearchImageButton_Click( object sender, ImageClickEventArgs e )
        {
            Response.Redirect( "SearchResult.aspx?Search=" + FindSearchText() );
        }

        protected void uxCouponImageButton_Click( object sender, ImageClickEventArgs e )
        {
            if (FindCouponID().Trim() != string.Empty)
                Response.Redirect( "Coupon.aspx?CouponID=" + FindCouponID() );
        }

        protected void uxLoginStatus_LoggedOut( object sender, EventArgs e )
        {
            if ( DataAccessContext.ApplicationSettings.ClearShoppingCartWhenLogout )
            {
                StoreContext.ShoppingCart.CartItems.Clear();
                StoreContext.CheckoutDetails.Clear();
            }
            
            string returnUrl = HttpContext.Current.Request.Url.AbsoluteUri;

            if (returnUrl.ToLower().Contains( "product.aspx" ))
            {
                string newUrl = returnUrl.Replace( "Product.aspx?ProductName=", "" ) + "-details.aspx";
                Response.Redirect( newUrl );
            }
        }
    }
}
