using System;
using System.Collections.Generic;
using System.Data;
using System.Text;
using System.Text.RegularExpressions;
using System.Xml;
using System.Xml.Serialization;

namespace Vevo.WebUI.Themes
{
    [Serializable]
    [XmlRoot( ElementName = "Theme" )]
    public class StoreTheme
    {
        #region Private

        private const string DefaultMasterPageName = "Front.master";

        private DataTable CreateThemeListTable()
        {
            // Create new DataTable.
            DataTable myDataTable = new DataTable( "ThemePageSource" );

            // Declare DataColumn variables.
            DataColumn myDataColumn;

            // Create new DataColumn, set DataType, ColumnName and add to DataTable.    
            myDataColumn = new DataColumn();
            myDataColumn.DataType = Type.GetType( "System.String" );
            myDataColumn.ColumnName = "MasterPage";
            myDataTable.Columns.Add( myDataColumn );

            myDataColumn = new DataColumn();
            myDataColumn.DataType = Type.GetType( "System.String" );
            myDataColumn.ColumnName = "Page";
            myDataColumn.Unique = true;
            myDataTable.Columns.Add( myDataColumn );

            return myDataTable;
        }

        private void AddMasterPageRow( DataTable table, string masterPage, string page )
        {
            if (!String.IsNullOrEmpty( masterPage ) || !String.IsNullOrEmpty( page ))
            {
                DataRow row = table.NewRow();
                row["MasterPage"] = masterPage;
                row["Page"] = page;
                table.Rows.Add( row );
            }
        }

        private DataTable GetThemeListTable()
        {
            DataTable table = CreateThemeListTable();
            try
            {
                if (MasterPages != null)
                {
                    foreach (StoreMasterPage masterPage in MasterPages)
                    {
                        if (masterPage.Pages != null)
                        {
                            foreach (string page in masterPage.Pages)
                            {
                                AddMasterPageRow( table, masterPage.FileName, page );
                            }
                        }
                    }
                }
            }
            catch (Exception ex)
            {
                throw new Exception( ex.Message );
            }
            finally
            {

            }
            return table;
        }

        private bool IsAbsolutePath( string path )
        {
            string trimmed = path.Trim();
            return trimmed.StartsWith( "~" ) ||
                trimmed.StartsWith( "/" ) ||
                trimmed.StartsWith( "\\" );
        }

        private string CheckPatternMasterPageName( string masterPage )
        {
            if (String.IsNullOrEmpty( masterPage ))
                return String.Format( "~/{0}", DefaultMasterPageName );
            else if (IsAbsolutePath( masterPage ))
                return String.Format( "{0}", masterPage );
            else
            {
                if (UrlManager.IsMobile())
                {
                    return String.Format( "~/Mobile/Themes/{0}/{1}", Name, masterPage );
                }
                else if (UrlManager.IsFacebook())
                {
                    return String.Format( "~/Facebook/Themes/{0}/{1}", Name, masterPage );
                }
                else if (UrlManager.IsBlog())
                {
                    return String.Format( "~/Blog/Themes/{0}/{1}", Name, masterPage );
                }
                else
                {
                    return String.Format( "~/Themes/{0}/{1}", Name, masterPage );
                }
            }
        }

        private string RemoveQueryString( string url )
        {
            int index = url.IndexOf( '?' );
            if (index == -1)
                return url;
            else
                return url.Substring( 0, index );
        }

        #endregion


        #region Public Properties

        public string Name;
        public string Author;
        public string AuthorUrl;
        public string Description;
        public string Version;
        public string VersionUrl;
        public StoreDefaultMaster DefaultMaster;

        [XmlArray( ElementName = "MasterPages" )]
        [XmlArrayItem( ElementName = "MasterPage" )]
        public StoreMasterPage[] MasterPages;

        #endregion


        #region Public Methods

        public static string GetXmlPath( string themeName )
        {
            if (UrlManager.IsMobile())
            {
                return String.Format( "~/Mobile/Themes/{0}/ThemeInfo.xml", themeName );
            }
            else if (UrlManager.IsFacebook())
            {
                return String.Format( "~/Facebook/Themes/{0}/ThemeInfo.xml", themeName );
            }
            else if (UrlManager.IsBlog())
            {
                return String.Format( "~/Blog/Themes/{0}/ThemeInfo.xml", themeName );
            }
            else
            {
                return String.Format( "~/Themes/{0}/ThemeInfo.xml", themeName );
            }
        }

        public string GetMasterPagePath( string pagePath )
        {
            DataTable table = GetThemeListTable();
            string nonParameterPagePath = RemoveQueryString( pagePath );

            DataRow[] rows = table.Select( String.Format( "Page = '{0}'", nonParameterPagePath ) );
            if (rows.Length > 0)
            {
                return CheckPatternMasterPageName( rows[0]["MasterPage"].ToString() );
            }
            else
            {
                StoreDefaultMaster storeDefaultMaster = DefaultMaster;
                return CheckPatternMasterPageName( storeDefaultMaster.FileName );
            }
        }

        #endregion

    }

}
