using System;
using System.Configuration;
using Vevo.Shared.Utilities;

namespace Vevo.WebAppLib
{
    /// <summary>
    /// Access application settings inside Web.Config.
    /// </summary>
    public static class WebConfiguration
    {
        private readonly static string _domainRegistrationKey;

        private readonly static bool _databaseAvailable = false;

        private readonly static string _dbConnectionString;
        private readonly static string _dbProviderName;

        private readonly static string _domainName;

        static WebConfiguration()
        {
            _domainRegistrationKey = ConfigurationManager.AppSettings.Get( "DomainRegistrationKey" );
            _domainName = ConfigurationManager.AppSettings.Get( "DomainName" );

            string valueText = ConfigurationManager.AppSettings.Get( "DatabaseAvailable" );
            if (valueText != null)
                _databaseAvailable = bool.Parse( valueText );

            if (_databaseAvailable)
            {
                ConnectionStringSettingsCollection connections = ConfigurationManager.ConnectionStrings;
                ConnectionStringSettings conn = connections[0];

                if (conn == null)
                {
                    throw new Exception(
                        "Please specify a database connection string " +
                        "called 'StoreConnection' (for PCI version) or 'MainConnection' (for non-PCI version) inside the <connectionStrings> section of Web.Config." );
                }

                _dbConnectionString =
                    ConfigurationManager
                    .ConnectionStrings[conn.Name]
                    .ConnectionString;
                _dbProviderName =
                    ConfigurationManager
                    .ConnectionStrings[conn.Name]
                    .ProviderName;
            }
        }

        //------------------------------------------------------------------------
        // Public methods
        //------------------------------------------------------------------------

        public static string DomainRegistrationKey
        {
            get
            {
                return _domainRegistrationKey;
            }
        }

        public static string DomainName
        {
            get
            {
                return _domainName;
            }
        }

        public static bool DatabaseAvailable
        {
            get
            {
                return _databaseAvailable;
            }
        }

        public static string DbConnectionString
        {
            get
            {
                return _dbConnectionString;
            }
        }

        public static string DbProviderName
        {
            get
            {
                return _dbProviderName;
            }
        }

        public static string DBConnectionStringPrefix
        {
            get
            {
                return ConfigurationManager.AppSettings["DBConnectionStringPrefix"];
            }
        }

        public static string GoogleEnvironment
        {
            get
            {
                return ConfigurationManager.AppSettings["GoogleEnvironment"];
            }
        }

        public static string GoogleMerchantID
        {
            get
            {
                return ConfigurationManager.AppSettings["GoogleMerchantID"];
            }
        }

        public static string GoogleMerchantKey
        {
            get
            {
                return ConfigurationManager.AppSettings["GoogleMerchantKey"];
            }
        }

        public static bool AdminSSLDisabled
        {
            get
            {
                return ConvertUtilities.ToBoolean(
                    ConfigurationManager.AppSettings["AdminSSLDisabled"] );
            }
        }

        public static string SecretKey
        {
            get
            {
                return ConfigurationManager.AppSettings["SecretKey"];
            }
        }

        public static string ProductDownloadPath
        {
            get
            {
                return ConfigurationManager.AppSettings["ProductDownloadPath"];
            }
        }

    }
}
